You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2017/11/07 09:26:04 UTC

[sling-org-apache-sling-discovery-base] 07/20: no-jira : increasing sleeps to account for another apache jenkins slowness - sling-trunk-1.7 2661

This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to annotated tag org.apache.sling.discovery.base-1.1.0
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-discovery-base.git

commit a55019dace5b16a72008a0a64b1ae9a8ab7f9cb6
Author: Stefan Egli <st...@apache.org>
AuthorDate: Thu Nov 5 09:50:27 2015 +0000

    no-jira : increasing sleeps to account for another apache jenkins slowness - sling-trunk-1.7 2661
    
    git-svn-id: https://svn.apache.org/repos/asf/sling/trunk/bundles/extensions/discovery/base@1712728 13f79535-47bb-0310-9956-ffa450edef68
---
 .../sling/discovery/base/its/AbstractSingleInstanceTest.java      | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java b/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
index d0b93e2..3ebf04a 100644
--- a/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
+++ b/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
@@ -97,8 +97,8 @@ public abstract class AbstractSingleInstanceTest {
         }
 
         instance.heartbeatsAndCheckView();
-        // wait 100ms for the vote to happen
-        Thread.sleep(100);
+        // wait 4000ms for the vote to happen
+        Thread.sleep(4000);
         
         assertNotNull(instance.getClusterViewService().getLocalClusterView());
         ClusterView cv = instance.getClusterViewService().getLocalClusterView();
@@ -137,8 +137,8 @@ public abstract class AbstractSingleInstanceTest {
         instance.bindPropertyProvider(pp, propertyName);
 
         instance.heartbeatsAndCheckView();
-        // wait 1000ms for the vote to happen
-        Thread.sleep(1000);
+        // wait 4000ms for the vote to happen
+        Thread.sleep(4000);
         assertEquals(propertyValue,
                 instance.getClusterViewService().getLocalClusterView()
                         .getInstances().get(0).getProperty(propertyName));

-- 
To stop receiving notification emails like this one, please contact
"commits@sling.apache.org" <co...@sling.apache.org>.